@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
@@ -187,6 +176,16 @@ class Shell(ActionInterpreter):
         Returns:
             str: Full filepath of executable.
         """
+        settings = config.plugins.shell[cls.name()]
+
+        if settings.executable_fullpath:
+            if not os.path.exists(settings.executable_fullpath):
+                raise RuntimeError(
+                    "Couldn't find executable '%s'." % settings.executable_fullpath
+                )
+            else:
+                return settings.executable_fullpath
+
         exe = which(name)
 
         if not exe and check_syspaths:
@@ -486,6 +485,7 @@ class UnixShell(Shell):
 
         if shell_command:  # an empty string means 'run no command and exit'
             executor.command(shell_command)
+
         executor.command("exit %s" % self.last_command_status)
 
         code = executor.get_output()
