@@ -888,7 +888,7 @@ class FileSystemPackageRepository(PackageRepository):
             .building file are created, so that we can safely delete cancelled
             variant dirs in the presence of multiple rez procs.
 
-            See https://github.com/nerdvegas/rez/issues/810
+            See #810
         """
         family_path = os.path.join(self.location, variant_resource.name)
         self._delete_stale_build_tagfiles(family_path)
